pub trait Point {
    fn pythagoras_theorem();
}

#[macro_export]
macro_rules! dprint {
    ( $( $x:expr ) => * ) => {
        {
            $(
                println!("{}", $x);
                )*
        }
    }
}

#[cfg(feature = "derive")]
pub use fraco_point_derive::*;
